/*
** Module   : DatabaseEventType.java
** Abstract : Database trigger event type.
**
** Copyright (c) 2013-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -------------------------------- Description --------------------------------
** 001 SVL 20130213 Created initial version.
** 002 OM  20131128 Added Assign and replication constants.
** 003 ECF 20140801 Added mask.
*/

package com.goldencode.p2j.persist.trigger;

/**
 * Database trigger event type. Each value has a unique mask value <code>&gt;= 0x01 and &lt;=
 * 0x80</code>, which allows multiple event types to be represented in an integral bit field.
 */
public enum DatabaseEventType
{
   ASSIGN(0x01),
   CREATE(0x02),
   DELETE(0x04),
   FIND(0x08),
   WRITE(0x10),
   REPLICATION_CREATE(0x20),
   REPLICATION_DELETE(0x40),
   REPLICATION_WRITE(0x80);
   
   /** Unique mask associated with this event type */
   private final int mask;
   
   /**
    * Constructor to set event type mask.
    * 
    * @param   mask
    *          Unique mask associated with this event type.
    */
   private DatabaseEventType(int mask)
   {
      this.mask = mask;
   }
   
   /**
    * Get the unique mask associated with this event type. This is used by {@link TriggerTracker}
    * to maintain state in a compact and fast storage mechanism about which trigger types are
    * registered for a record buffer at a given block level.
    * 
    * @return  Mask value (<code>&gt;= 0x01 and &lt;= 0x80</code>).
    */
   public int getMask()
   {
      return mask;
   }
}
